<?php
use Elementor\Widget_Base;
use Elementor\Controls_Manager;

if(!defined('ABSPATH')) exit;



class pc_pvt_content_on_elementor extends Widget_Base {
	
	 public function get_icon() {
      return 'emtr_lcweb_icon';
   }
	
	public function get_name() {
		return 'pc-pvt-content';
	}

	public function get_categories() {
		return array('privatecontent');
	}

   public function get_title() {
      return 'PC - '. __('Private Block', PC_ML);
   }



	// user categories array builder
	protected function pc_uc_array($bulk_opts = true, $apply_filter = true) {

		// fix for PCPP
		if(function_exists('pcpp_is_integrated_flag')) {
			pcpp_is_integrated_flag();	
		}
		
		
		$raw = pc_static::restr_opts_arr($bulk_opts, $apply_filter);
		
		$arr = array();
		foreach($raw as $block) {
			foreach($block['opts'] as $id => $name) {
				$arr[$id] = $name;	
			}
		}
		return $arr;
	}


	protected function _register_controls() {
		
		$lb_instances = array(
			'' => __('As default', PC_ML), 
			'none' => __('No login button', PC_ML)
		) + pc_static::get_lb_instances();




		$this->start_controls_section(
			'main',
			array(
				'label' => 'PrivateContent - '. __('Private Block', PC_ML),
			)
		);
  
  
		$this->add_control(
		   'allow',
		   array(
			  'label' 	=> __('Who can see contents?', 'gg_ml'),
			  'type' 	=> Controls_Manager::SELECT2,
			  'multiple'=> true,
			  'default' => current(array_keys( $this->pc_uc_array() )),
			  'options' => $this->pc_uc_array()
		   )
		);
		
		
		$this->add_control(
		   'block',
		   array(
			  'label' 	=> __('Who to block?', 'gg_ml'),
			  'type' 	=> Controls_Manager::SELECT2,
			  'multiple'=> true,
			  'default' => current(array_keys( $this->pc_uc_array(false) )),
			  'options' => $this->pc_uc_array(false)
		   )
		);
		
		
		$this->add_control(
		   'warning',
		   array(
			  'label' 		=> __('Show warning box?', 'gg_ml'),
			  'type' 		=> Controls_Manager::SWITCHER,
			  'default' 	=> '1',
			  'label_on' 	=> __('Yes'),
			  'label_off' 	=> __('No'),
			  'return_value' => '1',
		   )
		);
		
		
		$this->add_control(
		   'message',
		   array(
			  	'label' => __('Custom message for not allowed users', PC_ML),
				'type' 	=> Controls_Manager::TEXT,
				
				'condition' => array(
					'warning' => '1',
				),
		   )
		);
		
		
		$this->add_control(
		   'login_lb',
		   array(
			  'label' 	=> __("Login button's lightbox", PC_ML),
			  'type' 	=> Controls_Manager::SELECT,
			  'multiple'=> true,
			  'default' => current(array_keys( $lb_instances )),
			  'options' => $lb_instances,
			  
			  'condition' => array(
				  'warning' => '1',
			  ),
		   )
		);
		
		
		$this->add_control(
		   'registr_lb',
		   array(
			  'label' 	=> __("Registration button's lightbox", PC_ML),
			  'type' 	=> Controls_Manager::SELECT,
			  'multiple'=> true,
			  'default' => current(array_keys( $lb_instances )),
			  'options' => $lb_instances,
			  
			  'condition' => array(
				  'warning' => '1',
			  ),
		   )
		);
		
		
		// $this->add_control(
		//    'contents',
		//    array(
		// 	  	'label' => __("Contents to hide", "pc_ml"),
		// 		'type' => Controls_Manager::WYSIWYG,
		//    )
		// );

		$this->add_control(
			'content_type',
			[
				'label'       => esc_html__( 'Content Type', PC_ML),
				'type'        => Controls_Manager::SELECT,
				'default'     => 'template',
				'options'     => [
					'template' => esc_html__( 'Template', PC_ML),
					'editor'   => esc_html__( 'Editor', PC_ML),
				],
				'label_block' => 'true',
			]
		);

		$templates = \Elementor\Plugin::$instance->templates_manager->get_source( 'local' )->get_items();

		$options['0'] = '— ' . esc_html__( 'Select Template', PC_ML) . ' —';

		$types = array();
		if (count($templates)) {
			foreach($templates as $template) {
				$options[ $template['template_id'] ] = $template['title'] . ' (' . $template['type'] . ')';
				$types[ $template['template_id'] ] = $template['type'];
			}
		} else {
			$options['0'] = esc_html__('You haven\'t saved any templates yet.', PC_ML);
		}

		$this->add_control(
			'template_id',
			[
				'label'       => esc_html__( 'Choose Template', PC_ML ),
				'type'        => Controls_Manager::SELECT,
				'default'     => '0',
				'options'     => $options,
				'types'       => $types,
				'label_block' => 'true',
				'condition'   => [
					'content_type' => 'template',
				]
			]
		);

		$this->add_control(
			'editor_content',
			[
				'label'      => __( 'Content', PC_ML ),
				'type'       => Controls_Manager::WYSIWYG,
				'default'    => __( 'Content goes here.', PC_ML ),
				'dynamic' => [
					'active' => true,
				],
				'condition'   => [
					'content_type' => 'editor',
				]
			]
		);





		
		$this->end_controls_section();
   }


	
	////////////////////////


	protected function render() {
     	$vals = $this->get_settings();
		//var_dump($vals);

		$allow = implode(',', (array)$vals['allow']);
		$block = implode(',', (array)$vals['block']);
		
		$parts = array('warning', 'message', 'login_lb', 'registr_lb');
		$params = '';
		
		foreach($parts as $part) {
			$params .= $part.'="';

			if(!isset($vals[$part])) {$vals[$part] = '';}
			$params .= $vals[$part].'" ';	
		}

		switch ( $vals['content_type'] ) {
			case 'editor':		
				$content_html = $vals['editor_content'];
			break;

			case 'template':
				if ( '0' !== $vals['template_id'] ) {
					$template = \Elementor\Plugin::$instance->frontend->get_builder_content_for_display( $vals['template_id'] );

					if ( ! empty( $template ) ) {
						$content_html = \Elementor\Plugin::$instance->frontend->get_builder_content_for_display( $vals['template_id'] );
					} else {
						$content_html = '<span>' . esc_html__( 'The widget is working. Please, note, that you have to add a template to the library in order to be able to display it inside the widget.', PC_ML ) . '</span>';
					}
				} else {
					$content_html = '<span>' . esc_html__( 'The widget is working. Please, note, that you have to add a template to the library in order to be able to display it inside the widget.', PC_ML ) . '</span>';
				}
			break;

			default:
				return;
			break;
		}

		echo do_shortcode('[pc-pvt-content allow="'.$allow.'" block="'.$block.'" '. $params .']'. $content_html .'[/pc-pvt-content]');
	}


	protected function _content_template() {}
}
